@@ -4,18 +4,15 @@ commands (e.g. using `yum` as opposed to `apt`) we can make a one time call to
 that remote host and set all the special cases for running commands depending
 on the type of distribution/version we are dealing with.
 """
+import logging
+from ceph_deploy import exc
+from ceph_deploy.hosts import debian, centos, fedora, suse, remotes
+from ceph_deploy.connection import get_connection
 
-from ceph_deploy import lsb, exc
-from ceph_deploy.sudo_pushy import get_transport
-from ceph_deploy.hosts import debian, centos, fedora, suse
-
-# Import sudo_pushy and patch it
-import pushy
-from ceph_deploy import sudo_pushy
-sudo_pushy.patch()
+logger = logging.getLogger()
 
 
-def get(hostname, fallback=None):
+def get(hostname, username=None, fallback=None):
     """
     Retrieve the module that matches the distribution of a ``hostname``. This
     function will connect to that host and retrieve the distribution
@@ -32,14 +29,26 @@ def get(hostname, fallback=None):
     :param hostname: A hostname that is reachable/resolvable over the network
     :param fallback: Optional fallback to use if no supported distro is found
     """
-    sudo_conn = pushy.connect(get_transport(hostname))
-    (distro, release, codename) = lsb.get_lsb_release(sudo_conn)
+    conn = get_connection(
+        hostname,
+        username=username,
+        logger=logging.getLogger(hostname)
+    )
+    conn.import_module(remotes)
+    distro_name, release, codename = conn.remote_module.platform_information()
+    if not codename:
+        raise exc.UnsupportedPlatform(distro=distro_name, codename=codename)
 
-    module = _get_distro(distro)
-    module.name = distro
+    machine_type = conn.remote_module.machine_type()
+
+    module = _get_distro(distro_name)
+    module.name = distro_name
     module.release = release
     module.codename = codename
-    module.sudo_conn = sudo_conn
+    module.conn = conn
+    module.machine_type = machine_type
+    module.init = _choose_init(distro_name, codename)
+
     return module
 
 
@@ -64,8 +73,21 @@ def _get_distro(distro, fallback=None):
 
 def _normalized_distro_name(distro):
     distro = distro.lower()
-    if distro.startswith('redhat'):
+    if distro.startswith(('redhat', 'red hat')):
         return 'redhat'
-    elif distro.startswith('suse'):
+    elif distro.startswith(('scientific', 'scientific linux')):
+        return 'scientific'
+    elif distro.startswith(('suse', 'opensuse')):
         return 'suse'
     return distro
+
+
+def _choose_init(distro, codename):
+    """
+    Select a init system for a given distribution.
+
+    Returns the name of a init system (upstart, sysvinit ...).
+    """
+    if distro == 'Ubuntu':
+        return 'upstart'
+    return 'sysvinit'
